ethereum library

Classes

ConnectInfo
Interface for connection info used by Ethereum method.
CurrencyParams
Parameter for specifying currency, used in Ethereum.walletAddChain.
Ethereum
A Dart Ethereum Provider API for consistency across clients and applications.
ProviderMessage
Interface for provier message used by Ethereum method.
ProviderRpcError
Interface for provier error used by Ethereum method.

Properties

ethereum → Ethereum?
Getter for default Ethereum object, cycles through available injector in environment.
no setter

Functions

convertToDart(dynamic jsObject) → dynamic
Convert JS object to Dart object to avoid type error.
dartify(dynamic jsObject) → dynamic
Convert JS object to Dart object to avoid type error, same functionality as convertToDart;
stringify(dynamic obj) → String
Convert JavaScript object or value to a JSON string,