TransactionResponse class

A TransactionResponse includes all properties of a Transaction as well as several properties that are useful once it has been mined.

Inheritance

Properties

accessList → AccessList?
The AccessList included in an EIP-2930 or EIP-1559 transaction.
no setter
blockHash → String?
The hash of the block this transaction was mined in. If the block has not been mined, this is null.
no setter
blockNumber → int?
The number ("height") of the block this transaction was mined in. If the block has not been mined, this is null.
no setter
chainId → int
The chain ID for transaction. This is used as part of EIP-155 to prevent replay attacks on different networks.
no setterinherited
confirmations → int
The number of blocks that have been mined (including the initial block) since this transaction was mined.
no setter
data → String
The data for transaction. In a contract this is the call data.
no setterinherited
from → String
The address transaction is from.
no setterinherited
gasLimit → BigInt
The gas limit for transaction.
no setterinherited
gasPrice → BigInt?
The price (in wei) per unit of gas for transaction.
no setterinherited
hash → String
The transaction hash, which can be used as an identifier for transaction. This is the keccak256 of the serialized RLP encoded representation of transaction.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
maxFeePerGas → BigInt?
The maximum price (in wei) per unit of gas for transaction.
no setterinherited
maxPriorityFeePerGas → BigInt?
The priority fee price (in wei) per unit of gas for transaction.
no setterinherited
nounce → int
The nonce for transaction.
no setterinherited
r → String
The r portion of the elliptic curve signatures for transaction.
no setterinherited
raw → String?
The serialized transaction.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s → String
The s portion of the elliptic curve signatures for transaction.
no setterinherited
timestamp → DateTime?
The timestamp of the block this transaction was mined in. If the block has not been mined, this is null.
no setter
to → String?
The address transaction is to.
no setterinherited
type → int?
The EIP-2718 type of this transaction envelope, or null for legacy transactions that do not have an envelope.
no setter
v → int
The v portion of the elliptic curve signatures for transaction.
no setterinherited
value → BigInt
The value (in wei) for transaction.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
wait([int? confirms]) → Future<TransactionReceipt>
Wait for this hash transaction to be mined with confirms confirmations, same as Provider.waitForTransaction.

Operators

operator ==(Object other) → bool
The equality operator.
inherited